%define lib_name_orig	libaqsis
%define major		1
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%global _python_bytecompile_extra 0

Summary:	RenderMan-compliant 3D rendering solution
Name:		aqsis
Version:	1.8.2
Release:	%mkrel 43
License:	GPLv2+ and BSD
Group:		Graphics/3D
Url:		https://www.aqsis.org/
Source0:	https://downloads.sourceforge.net/aqsis/%{name}-%{version}.tar.gz
# Use own desktop file because of dead upstream
Source1:	eqsl.desktop
# Fix code to be C++11 compatible https://sourceforge.net/p/aqsis/bugs/433/
Patch2:		aqsis-1.8.2-gcc6.patch
# Fix linking
Patch3:		aqsis-1.8.2-pthread.patch
# Fix build with boost 1.83
Patch4:		aqsis-boost1.83.patch
# From Gentoo
Patch10:	aqsis-1.8.2-openexr-compat.patch
Patch11:	aqsis-1.8.2-pfto-boost-1.59.patch
Patch12:	aqsis-1.8.2-boost-join-moc.patch
# From Alt
Patch50:	aqsis-gcc11.patch
Patch101:	aqsis-1.8.2-missing-includes.patch

# Fix build with openexr3 (in a bit hacky way)
Patch200:       aqsis-openexr3.patch

BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	qt4-devel
BuildRequires:	cmake
BuildRequires:	libxslt-proc
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	boost-devel

%description
Tha Aqsis rendering system consists of a set of libraries and applications for
creating high-quality computer imagery using the Pixar RenderMan Interface.

%package -n %{libname}
Summary:	Aqsis library
Group:		System/Libraries

%description -n %{libname}
The Aqsis library.

%package -n %{develname}
Summary:	Development files for Aqsis
Group:		Development/C++
Requires:	%{libname} >= %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
The Aqsis library developpement files.

%prep
%setup -q
%autopatch -p1
cp -f %{SOURCE1} distribution/linux/

# fix build with boost >= 1.72.0
#sed -i -e 's,boost/timer.hpp,boost/timer/timer.hpp,g' $(grep -rl 'boost/timer.hpp')
sed -i -e 's,boost::shared_ptr,std::shared_ptr,g' $(grep -rl boost::shared_ptr)
sed -i -e 's,boost::static_pointer_cast,std::static_pointer_cast,g' $(grep -rl boost::static_pointer_cast)
sed -i -e 's,boost::enable_shared_from_this,std::enable_shared_from_this,g' $(grep -rl boost::enable_shared_from_this)
sed -i -e 's,boost::weak_ptr,std::weak_ptr,g' $(grep -rl boost::weak_ptr)

%build
export CXXFLAGS="%{optflags} -Wno-deprecated -Wno-deprecated-declarations"
%cmake \
    -Wno-dev \
    -DAQSIS_USE_RPATH:BOOL=OFF \
    -DSYSCONFDIR:STRING=%{_sysconfdir} \
    -DLIBDIR:STRING=%{_libdir} \
    -DDEFAULT_DISPLAYPATH:STRING=%{_libdir}/%{name}

%cmake_build

%install
%cmake_install

%files
%doc AUTHORS README
%config(noreplace) %{_sysconfdir}/*
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/mime/packages/aqsis.xml
%{_datadir}/pixmaps/*.png
%{_iconsdir}/hicolor/*/mimetypes/*.png

%files -n %{libname}
%{_libdir}/%{name}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/*.so
%{_includedir}/*


%changelog
* Fri Jan 12 2024 wally <wally> 1.8.2-43.mga10
+ Revision: 2030516
- rebuild for boost 1.84.0

* Thu Sep 28 2023 wally <wally> 1.8.2-42.mga10
+ Revision: 1991904
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 1.8.2-41.mga9
+ Revision: 1926454
- rebuild for boost 1.81.0

* Mon Dec 12 2022 ns80 <ns80> 1.8.2-40.mga9
+ Revision: 1920979
- rebuild for new libtiff

* Sun Jul 03 2022 wally <wally> 1.8.2-39.mga9
+ Revision: 1867228
- rebuild for boost 1.79.0

* Sun Apr 03 2022 umeabot <umeabot> 1.8.2-38.mga9
+ Revision: 1841529
- Mageia 9 Mass Rebuild

* Sun Dec 26 2021 wally <wally> 1.8.2-37.mga9
+ Revision: 1764142
- add patch to fix build with openexr3
- rebuild for openexr 3.1.3

* Sun Dec 19 2021 wally <wally> 1.8.2-36.mga9
+ Revision: 1762638
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 1.8.2-35.mga9
+ Revision: 1744787
- add patch to fix missing includes
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.8.2-34.mga9
+ Revision: 1723062
- add patch from Alt to fix build with gcc 11
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 1.8.2-33.mga8
+ Revision: 1666734
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.8.2-32.mga8
+ Revision: 1661976
- rebuild for boost 1.74.0

* Sat Sep 12 2020 daviddavid <daviddavid> 1.8.2-31.mga8
+ Revision: 1625029
- rebuild for new openexr 2.5.3

* Sun May 03 2020 wally <wally> 1.8.2-30.mga8
+ Revision: 1578030
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 1.8.2-29.mga8
+ Revision: 1545012
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 1.8.2-28.mga8
+ Revision: 1483498
- rebuild for boost 1.72.0
- build with new cmake macros

* Wed Oct 17 2018 wally <wally> 1.8.2-27.mga7
+ Revision: 1321702
- add patch to fix linking
- rebuild for new boost 1.68.0

* Mon Oct 15 2018 daviddavid <daviddavid> 1.8.2-26.mga7
+ Revision: 1320423
- rebuild for new ilmbase 2.3.0

* Fri Sep 21 2018 umeabot <umeabot> 1.8.2-25.mga7
+ Revision: 1294478
- Mageia 7 Mass Rebuild

* Sun May 27 2018 wally <wally> 1.8.2-24.mga7
+ Revision: 1232482
- sync patches with Gentoo
- rebuild for openexr 2.2.1

* Sat Jan 13 2018 wally <wally> 1.8.2-23.mga7
+ Revision: 1192556
- rebuild for new ilmbase

* Mon Dec 25 2017 wally <wally> 1.8.2-22.mga7
+ Revision: 1184651
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 1.8.2-21.mga7
+ Revision: 1178310
- rebuild for boost 1.65
- rebuild for boost 1.65

* Sat Sep 16 2017 daviddavid <daviddavid> 1.8.2-19.mga7
+ Revision: 1154700
- add patch to fix build with gcc6+
+ tv <tv>
- rebuild with latest boost

* Sat Dec 26 2015 daviddavid <daviddavid> 1.8.2-18.mga6
+ Revision: 915151
- rebuild for new boost 1.60.0

* Mon Sep 28 2015 daviddavid <daviddavid> 1.8.2-17.mga6
+ Revision: 884372
- rebuild for new boost 1.59.0
- add patch1 from Fedora to fix build with boost 1.59.0

* Sun Aug 30 2015 fwang <fwang> 1.8.2-16.mga6
+ Revision: 871146
- rebuild for new boost

* Thu Nov 27 2014 alexl <alexl> 1.8.2-15.mga5
+ Revision: 799551
- translated desktop file (dead upstream)

* Wed Oct 15 2014 umeabot <umeabot> 1.8.2-14.mga5
+ Revision: 742074
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.8.2-13.mga5
+ Revision: 677878
- Mageia 5 Mass Rebuild

* Sun Aug 24 2014 luigiwalser <luigiwalser> 1.8.2-12.mga5
+ Revision: 666986
- rebuild for ilmbase and OpenEXR

* Fri Apr 25 2014 akien <akien> 1.8.2-11.mga5
+ Revision: 618076
- Rebuild for new OpenEXR and IlmBase

* Sat Feb 08 2014 barjac <barjac> 1.8.2-10.mga5
+ Revision: 585921
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 1.8.2-9.mga4
+ Revision: 534487
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 fwang <fwang> 1.8.2-8.mga4
+ Revision: 478010
- fix build with openexr 2.0 (patch from archlinux)
- rebuild for new openexr

* Tue Jul 09 2013 fwang <fwang> 1.8.2-7.mga4
+ Revision: 451698
- rebuild for new boost

* Sun Jun 02 2013 fwang <fwang> 1.8.2-6.mga4
+ Revision: 434983
- rebuild for new libpng

* Thu Apr 11 2013 barjac <barjac> 1.8.2-5.mga3
+ Revision: 409766
- rebuild for boost-1.53

* Fri Jan 11 2013 umeabot <umeabot> 1.8.2-4.mga3
+ Revision: 345991
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 1.8.2-3.mga3
+ Revision: 332930
- rebuild for new boost

* Sun Dec 02 2012 fwang <fwang> 1.8.2-2.mga3
+ Revision: 324993
- rebuild for new openexr

* Wed Nov 28 2012 fwang <fwang> 1.8.2-1.mga3
+ Revision: 322495
- update rpm group
- new version 1.8.2

* Tue Jul 31 2012 fwang <fwang> 1.8.1-1.mga3
+ Revision: 276515
- br flex
- new version 1.8.1
- do not specify filesystemversion
- rebuild for new boost

* Tue May 29 2012 kamil <kamil> 1.6.0-15.mga3
+ Revision: 248958
- rebuild against boost 1.49.0

* Fri Dec 23 2011 fwang <fwang> 1.6.0-14.mga2
+ Revision: 186410
- fix build with gcc 4.6
- rebuild for new tiff

* Mon Nov 28 2011 fwang <fwang> 1.6.0-13.mga2
+ Revision: 173453
- rebuild for new boost
- rebuild for new boost

* Mon Jul 11 2011 fwang <fwang> 1.6.0-11.mga2
+ Revision: 122103
- rebuild for new fltk

* Wed Jun 22 2011 fwang <fwang> 1.6.0-10.mga2
+ Revision: 111859
- rebuild for new boost

* Tue Jun 21 2011 dmorgan <dmorgan> 1.6.0-9.mga2
+ Revision: 111346
- Rebuild against new boost

* Wed Mar 23 2011 dmorgan <dmorgan> 1.6.0-8.mga1
+ Revision: 75783
- Remove mdv macros
- imported package aqsis


* Mon Mar 14 2011 Funda Wang <fwang@mandriva.org> 1.6.0-8mdv2011.0
+ Revision: 644459
- force filesystem v2
- rebuild for new boost

* Wed Feb 02 2011 Funda Wang <fwang@mandriva.org> 1.6.0-7
+ Revision: 634996
- rebuild
- tighten BR

* Mon Aug 23 2010 Funda Wang <fwang@mandriva.org> 1.6.0-6mdv2011.0
+ Revision: 572128
- rebuild for new boost

* Wed Aug 04 2010 Funda Wang <fwang@mandriva.org> 1.6.0-5mdv2011.0
+ Revision: 565987
- rebuild for new boost

* Mon Feb 08 2010 Anssi Hannula <anssi@mandriva.org> 1.6.0-4mdv2010.1
+ Revision: 501882
- rebuild for new boost

* Wed Feb 03 2010 Funda Wang <fwang@mandriva.org> 1.6.0-3mdv2010.1
+ Revision: 500314
- rebuild for new boost

* Mon Jan 18 2010 Jérôme Brenier <incubusss@mandriva.org> 1.6.0-2mdv2010.1
+ Revision: 493158
- rebuild for new fltk

* Wed Nov 11 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.6.0-1mdv2010.1
+ Revision: 464841
- package missing file
- update to new version 1.6.0
- drop both patches, fixed upstream

* Fri Aug 21 2009 Funda Wang <fwang@mandriva.org> 1.4.2-3mdv2010.0
+ Revision: 418838
- sync with fedora patches

* Thu Mar 12 2009 Emmanuel Andry <eandry@mandriva.org> 1.4.2-2mdv2009.1
+ Revision: 354286
- rebuild for new boost

* Tue Jan 27 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.2-1mdv2009.1
+ Revision: 334592
- update to new version 1.4.2

* Mon Dec 22 2008 Funda Wang <fwang@mandriva.org> 1.4.1-4mdv2009.1
+ Revision: 317400
- rebuild for new boost

* Sat Dec 13 2008 Funda Wang <fwang@mandriva.org> 1.4.1-3mdv2009.1
+ Revision: 313951
- rebuild
- rebuild

* Sun Sep 28 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.1-1mdv2009.1
+ Revision: 289051
- update to new version 1.4.1

* Mon Aug 18 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.4.0-3mdv2009.0
+ Revision: 273429
- rebuild against new boost

* Tue Aug 12 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.0-2mdv2009.0
+ Revision: 270970
- install libraries to %%_libdir on x86_64
- add buildrequires on libjpeg-devel
- fix building by removing not clean build directory and setting right suffix for boost libraries
- fix file list
- update to new version 1.4.0
- adjust buildrequires
- upstream uses cmake instead of scons

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 1.2.0-3mdv2008.1
+ Revision: 170766
- rebuild
- better summaries
- summary is not licence tag

* Tue Jan 08 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.2.0-2mdv2008.1
+ Revision: 146896
- obsolete older devel library
- new license policy
- new devel library policy
- fix mixture of tabs and spaces into spec file
- do not package COPYING and INSTALL files
- spec file clean
- update link in URL
- update Source link

  + Thierry Vignaud <tv@mandriva.org>
    - fix mesaglu-devel BR

* Thu Dec 20 2007 Olivier Blin <oblin@mandriva.com> 1.2.0-1mdv2008.1
+ Revision: 135823
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - buildrequires X11-devel instead of XFree86-devel


* Mon Feb 19 2007 Pascal Terjan <pterjan@mandriva.org> 1.2.0-1mdv2007.0
+ Revision: 122889
- fix release
- 1.2.0 final
- Drop patch0

* Wed Jan 03 2007 Pascal Terjan <pterjan@mandriva.org> 1.2.0-0.20061223.2mdv2007.1
+ Revision: 103796
- Fix generated dependency on /usr/sbin/bash (aka test your package after the very last commit)

* Wed Jan 03 2007 Pascal Terjan <pterjan@mandriva.org> 1.2.0-0.20061223.1mdv2007.1
+ Revision: 103672
- fix lib64
- have the scripts executable
- Add x86_64 patch from Fedora
- Buildrequires boost-devel
- move .a to -devel
- really use mkrel
- mark the config file
- partially sync with upstream specfile
- don't separate build and install as the scons script do te same...
- fix file list
- 1.2.0 snapshot (almost RC1)
- switch to scons
- mkrel
- Import aqsis

* Fri May 06 2005 Pascal Terjan <pterjan@mandriva.org> 1.0.0-3mdk
- better fix for x86_64 build

* Thu May 05 2005 Pascal Terjan <pterjan@mandriva.org> 1.0.0-2mdk
- fix x86_64 build (P1)

* Mon Jan 17 2005 Pascal Terjan <pterjan@mandrake.org> 1.0.0-1mdk
- 1.0.0

* Sun Jan 16 2005 Pascal Terjan <pterjan@mandrake.org> 0.9.3-1mdk
- 0.9.3
- BuildRequires fltk-devel

* Sun Sep 05 2004 Pascal Terjan <pterjan@mandrakesoft.com> 0.9.2-1mdk
- New release 0.9.2
- Drop patch 0 (fixed upstream)

* Wed Jun 09 2004 Pascal Terjan <pterjan@mandrake.org> 0.9.1-2mdk
- GCC 3.4 fixes

* Fri Apr 09 2004 Pascal Terjan <pterjan@mandrake.org> 0.9.1-1mdk
- 0.9.1

